==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/CallGraphPack.h <==
// public class soot.jimple.toolkits.callgraph.CallGraphPack

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 65aca5ceab69719a soot_Pack
// @dep_class 86700b06d7b70b0e soot_RadioScenePack
// @dep_class 4847c782d4c3e1d9 soot_ScenePack
// @dep_class a13a4618053776b8 soot_jimple_toolkits_callgraph_CallGraphPack

// header file dependencies
// @dep_header soot_RadioScenePack

#include "soot/RadioScenePack.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_CallGraphPack_H_
#define _JC_soot_jimple_toolkits_callgraph_CallGraphPack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_refs	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$refs	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$object	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vmethods	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtable	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtype	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_CallGraphPack$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_CallGraphPack$method$internalApply$e44bdfd255a61742(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraphPack$method_info$internalApply$e44bdfd255a61742;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vmethods {
	void	(*internalApply$e44bdfd255a61742)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Pack$vmethods	soot_Pack;
	_jc_soot_ScenePack$vmethods	soot_ScenePack;
	_jc_soot_RadioScenePack$vmethods	soot_RadioScenePack;
	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vmethods	soot_jimple_toolkits_callgraph_CallGraphPack;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$refs {
    _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_refs	soot_jimple_toolkits_callgraph_CallGraphPack;
    _jc_soot_RadioScenePack$sub_refs	soot_RadioScenePack;
    _jc_soot_ScenePack$sub_refs	soot_ScenePack;
    _jc_soot_Pack$sub_refs	soot_Pack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Pack$sub_nonrefs	soot_Pack;
    _jc_soot_ScenePack$sub_nonrefs	soot_ScenePack;
    _jc_soot_RadioScenePack$sub_nonrefs	soot_RadioScenePack;
    _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_nonrefs	soot_jimple_toolkits_callgraph_CallGraphPack;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$object {
	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtype _jc_soot_jimple_toolkits_callgraph_CallGraphPack$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_CallGraphPack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_CallGraphPack$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_CallGraphPack_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/CallGraphPack.h <==
// public class soot.jimple.toolkits.callgraph.CallGraphPack

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 65aca5ceab69719a soot_Pack
// @dep_class 86700b06d7b70b0e soot_RadioScenePack
// @dep_class 4847c782d4c3e1d9 soot_ScenePack
// @dep_class a13a4618053776b8 soot_jimple_toolkits_callgraph_CallGraphPack

// header file dependencies
// @dep_header soot_RadioScenePack

#include "soot/RadioScenePack.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_CallGraphPack_H_
#define _JC_soot_jimple_toolkits_callgraph_CallGraphPack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_refs	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$refs	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$object	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vmethods	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtable	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtype	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_CallGraphPack$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_CallGraphPack$method$internalApply$e44bdfd255a61742(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraphPack$method_info$internalApply$e44bdfd255a61742;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vmethods {
	void	(*internalApply$e44bdfd255a61742)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Pack$vmethods	soot_Pack;
	_jc_soot_ScenePack$vmethods	soot_ScenePack;
	_jc_soot_RadioScenePack$vmethods	soot_RadioScenePack;
	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vmethods	soot_jimple_toolkits_callgraph_CallGraphPack;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$refs {
    _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_refs	soot_jimple_toolkits_callgraph_CallGraphPack;
    _jc_soot_RadioScenePack$sub_refs	soot_RadioScenePack;
    _jc_soot_ScenePack$sub_refs	soot_ScenePack;
    _jc_soot_Pack$sub_refs	soot_Pack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Pack$sub_nonrefs	soot_Pack;
    _jc_soot_ScenePack$sub_nonrefs	soot_ScenePack;
    _jc_soot_RadioScenePack$sub_nonrefs	soot_RadioScenePack;
    _jc_soot_jimple_toolkits_callgraph_CallGraphPack$sub_nonrefs	soot_jimple_toolkits_callgraph_CallGraphPack;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraphPack$object {
	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_CallGraphPack$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_CallGraphPack$vtype _jc_soot_jimple_toolkits_callgraph_CallGraphPack$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_CallGraphPack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_CallGraphPack$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_CallGraphPack_H_ */
